==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/scheduler/kotlin/inputs/JobErrorActionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.scheduler.kotlin.inputs

import com.pulumi.azurenative.scheduler.inputs.JobErrorActionArgs.builder
import com.pulumi.azurenative.scheduler.kotlin.enums.JobActionType
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property queueMessage Gets or sets the storage queue message.
 * @property request Gets or sets the http requests.
 * @property retryPolicy Gets or sets the retry policy.
 * @property serviceBusQueueMessage Gets or sets the service bus queue message.
 * @property serviceBusTopicMessage Gets or sets the service bus topic message.
 * @property type Gets or sets the job error action type.
 */
public data class JobErrorActionArgs(
    public val queueMessage: Output<StorageQueueMessageArgs>? = null,
    public val request: Output<HttpRequestArgs>? = null,
    public val retryPolicy: Output<RetryPolicyArgs>? = null,
    public val serviceBusQueueMessage: Output<ServiceBusQueueMessageArgs>? = null,
    public val serviceBusTopicMessage: Output<ServiceBusTopicMessageArgs>? = null,
    public val type: Output<JobActionType>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.scheduler.inputs.JobErrorActionArgs> {
    override fun toJava(): com.pulumi.azurenative.scheduler.inputs.JobErrorActionArgs =
        com.pulumi.azurenative.scheduler.inputs.JobErrorActionArgs.builder()
            .queueMessage(queueMessage?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .request(request?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .retryPolicy(retryPolicy?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .serviceBusQueueMessage(
                serviceBusQueueMessage?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .serviceBusTopicMessage(
                serviceBusTopicMessage?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .type(type?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [JobErrorActionArgs].
 */
@PulumiTagMarker
public class JobErrorActionArgsBuilder internal constructor() {
    private var queueMessage: Output<StorageQueueMessageArgs>? = null

    private var request: Output<HttpRequestArgs>? = null

    private var retryPolicy: Output<RetryPolicyArgs>? = null

    private var serviceBusQueueMessage: Output<ServiceBusQueueMessageArgs>? = null

    private var serviceBusTopicMessage: Output<ServiceBusTopicMessageArgs>? = null

    private var type: Output<JobActionType>? = null

    /**
     * @param value Gets or sets the storage queue message.
     */
    @JvmName("lcdnxxcvoqittqqv")
    public suspend fun queueMessage(`value`: Output<StorageQueueMessageArgs>) {
        this.queueMessage = value
    }

    /**
     * @param value Gets or sets the http requests.
     */
    @JvmName("mccmjrukokttjwci")
    public suspend fun request(`value`: Output<HttpRequestArgs>) {
        this.request = value
    }

    /**
     * @param value Gets or sets the retry policy.
     */
    @JvmName("hmobvfuwwseqshit")
    public suspend fun retryPolicy(`value`: Output<RetryPolicyArgs>) {
        this.retryPolicy = value
    }

    /**
     * @param value Gets or sets the service bus queue message.
     */
    @JvmName("qjguyvoajckowsta")
    public suspend fun serviceBusQueueMessage(`value`: Output<ServiceBusQueueMessageArgs>) {
        this.serviceBusQueueMessage = value
    }

    /**
     * @param value Gets or sets the service bus topic message.
     */
    @JvmName("yfrknspckkulchnd")
    public suspend fun serviceBusTopicMessage(`value`: Output<ServiceBusTopicMessageArgs>) {
        this.serviceBusTopicMessage = value
    }

    /**
     * @param value Gets or sets the job error action type.
     */
    @JvmName("oclksejwkymedtdr")
    public suspend fun type(`value`: Output<JobActionType>) {
        this.type = value
    }

    /**
     * @param value Gets or sets the storage queue message.
     */
    @JvmName("lflbxduneqgvvdhg")
    public suspend fun queueMessage(`value`: StorageQueueMessageArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.queueMessage = mapped
    }

    /**
     * @param argument Gets or sets the storage queue message.
     */
    @JvmName("ucotwejkvkcvptjb")
    public suspend fun queueMessage(argument: suspend StorageQueueMessageArgsBuilder.() -> Unit) {
        val toBeMapped = StorageQueueMessageArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.queueMessage = mapped
    }

    /**
     * @param value Gets or sets the http requests.
     */
    @JvmName("xbmwmupvvwqgvjfc")
    public suspend fun request(`value`: HttpRequestArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.request = mapped
    }

    /**
     * @param argument Gets or sets the http requests.
     */
    @JvmName("mawsexfsgogivbvq")
    public suspend fun request(argument: suspend HttpRequestArgsBuilder.() -> Unit) {
        val toBeMapped = HttpRequestArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.request = mapped
    }

    /**
     * @param value Gets or sets the retry policy.
     */
    @JvmName("sojopowtlcmghnsq")
    public suspend fun retryPolicy(`value`: RetryPolicyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.retryPolicy = mapped
    }

    /**
     * @param argument Gets or sets the retry policy.
     */
    @JvmName("lnmtrvfsqwewuaiv")
    public suspend fun retryPolicy(argument: suspend RetryPolicyArgsBuilder.() -> Unit) {
        val toBeMapped = RetryPolicyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.retryPolicy = mapped
    }

    /**
     * @param value Gets or sets the service bus queue message.
     */
    @JvmName("jfypdadfcmoqjtxs")
    public suspend fun serviceBusQueueMessage(`value`: ServiceBusQueueMessageArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceBusQueueMessage = mapped
    }

    /**
     * @param argument Gets or sets the service bus queue message.
     */
    @JvmName("merqpojhipudcmby")
    public suspend
    fun serviceBusQueueMessage(argument: suspend ServiceBusQueueMessageArgsBuilder.() -> Unit) {
        val toBeMapped = ServiceBusQueueMessageArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.serviceBusQueueMessage = mapped
    }

    /**
     * @param value Gets or sets the service bus topic message.
     */
    @JvmName("qtjahqnagdojsffl")
    public suspend fun serviceBusTopicMessage(`value`: ServiceBusTopicMessageArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceBusTopicMessage = mapped
    }

    /**
     * @param argument Gets or sets the service bus topic message.
     */
    @JvmName("vuatuvgrcebmeyyw")
    public suspend
    fun serviceBusTopicMessage(argument: suspend ServiceBusTopicMessageArgsBuilder.() -> Unit) {
        val toBeMapped = ServiceBusTopicMessageArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.serviceBusTopicMessage = mapped
    }

    /**
     * @param value Gets or sets the job error action type.
     */
    @JvmName("iarohbjhhtgjuldy")
    public suspend fun type(`value`: JobActionType?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): JobErrorActionArgs = JobErrorActionArgs(
        queueMessage = queueMessage,
        request = request,
        retryPolicy = retryPolicy,
        serviceBusQueueMessage = serviceBusQueueMessage,
        serviceBusTopicMessage = serviceBusTopicMessage,
        type = type,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/scheduler/kotlin/inputs/JobErrorActionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.scheduler.kotlin.inputs

import com.pulumi.azurenative.scheduler.inputs.JobErrorActionArgs.builder
import com.pulumi.azurenative.scheduler.kotlin.enums.JobActionType
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property queueMessage Gets or sets the storage queue message.
 * @property request Gets or sets the http requests.
 * @property retryPolicy Gets or sets the retry policy.
 * @property serviceBusQueueMessage Gets or sets the service bus queue message.
 * @property serviceBusTopicMessage Gets or sets the service bus topic message.
 * @property type Gets or sets the job error action type.
 */
public data class JobErrorActionArgs(
    public val queueMessage: Output<StorageQueueMessageArgs>? = null,
    public val request: Output<HttpRequestArgs>? = null,
    public val retryPolicy: Output<RetryPolicyArgs>? = null,
    public val serviceBusQueueMessage: Output<ServiceBusQueueMessageArgs>? = null,
    public val serviceBusTopicMessage: Output<ServiceBusTopicMessageArgs>? = null,
    public val type: Output<JobActionType>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.scheduler.inputs.JobErrorActionArgs> {
    override fun toJava(): com.pulumi.azurenative.scheduler.inputs.JobErrorActionArgs =
        com.pulumi.azurenative.scheduler.inputs.JobErrorActionArgs.builder()
            .queueMessage(queueMessage?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .request(request?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .retryPolicy(retryPolicy?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .serviceBusQueueMessage(
                serviceBusQueueMessage?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .serviceBusTopicMessage(
                serviceBusTopicMessage?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .type(type?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [JobErrorActionArgs].
 */
@PulumiTagMarker
public class JobErrorActionArgsBuilder internal constructor() {
    private var queueMessage: Output<StorageQueueMessageArgs>? = null

    private var request: Output<HttpRequestArgs>? = null

    private var retryPolicy: Output<RetryPolicyArgs>? = null

    private var serviceBusQueueMessage: Output<ServiceBusQueueMessageArgs>? = null

    private var serviceBusTopicMessage: Output<ServiceBusTopicMessageArgs>? = null

    private var type: Output<JobActionType>? = null

    /**
     * @param value Gets or sets the storage queue message.
     */
    @JvmName("achewsludpsjhqyi")
    public suspend fun queueMessage(`value`: Output<StorageQueueMessageArgs>) {
        this.queueMessage = value
    }

    /**
     * @param value Gets or sets the http requests.
     */
    @JvmName("ngfarbvlfkxmghds")
    public suspend fun request(`value`: Output<HttpRequestArgs>) {
        this.request = value
    }

    /**
     * @param value Gets or sets the retry policy.
     */
    @JvmName("nejtifpeuwqsdsfy")
    public suspend fun retryPolicy(`value`: Output<RetryPolicyArgs>) {
        this.retryPolicy = value
    }

    /**
     * @param value Gets or sets the service bus queue message.
     */
    @JvmName("jbknlcpclitvfdxs")
    public suspend fun serviceBusQueueMessage(`value`: Output<ServiceBusQueueMessageArgs>) {
        this.serviceBusQueueMessage = value
    }

    /**
     * @param value Gets or sets the service bus topic message.
     */
    @JvmName("cscbdbxkwoakjpqy")
    public suspend fun serviceBusTopicMessage(`value`: Output<ServiceBusTopicMessageArgs>) {
        this.serviceBusTopicMessage = value
    }

    /**
     * @param value Gets or sets the job error action type.
     */
    @JvmName("ylauuahrqcrgmmxq")
    public suspend fun type(`value`: Output<JobActionType>) {
        this.type = value
    }

    /**
     * @param value Gets or sets the storage queue message.
     */
    @JvmName("psuyibmbgjnjbdfg")
    public suspend fun queueMessage(`value`: StorageQueueMessageArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.queueMessage = mapped
    }

    /**
     * @param argument Gets or sets the storage queue message.
     */
    @JvmName("hufrmuuwlbesdjri")
    public suspend fun queueMessage(argument: suspend StorageQueueMessageArgsBuilder.() -> Unit) {
        val toBeMapped = StorageQueueMessageArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.queueMessage = mapped
    }

    /**
     * @param value Gets or sets the http requests.
     */
    @JvmName("efdlbdvwyqafclkr")
    public suspend fun request(`value`: HttpRequestArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.request = mapped
    }

    /**
     * @param argument Gets or sets the http requests.
     */
    @JvmName("rnfixirktucfbaux")
    public suspend fun request(argument: suspend HttpRequestArgsBuilder.() -> Unit) {
        val toBeMapped = HttpRequestArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.request = mapped
    }

    /**
     * @param value Gets or sets the retry policy.
     */
    @JvmName("awmctwoawdlolnqx")
    public suspend fun retryPolicy(`value`: RetryPolicyArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.retryPolicy = mapped
    }

    /**
     * @param argument Gets or sets the retry policy.
     */
    @JvmName("mxdscshnjlkwrkeu")
    public suspend fun retryPolicy(argument: suspend RetryPolicyArgsBuilder.() -> Unit) {
        val toBeMapped = RetryPolicyArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.retryPolicy = mapped
    }

    /**
     * @param value Gets or sets the service bus queue message.
     */
    @JvmName("wjgpnqvgyhersejd")
    public suspend fun serviceBusQueueMessage(`value`: ServiceBusQueueMessageArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceBusQueueMessage = mapped
    }

    /**
     * @param argument Gets or sets the service bus queue message.
     */
    @JvmName("ctupexlattbfxxmi")
    public suspend
    fun serviceBusQueueMessage(argument: suspend ServiceBusQueueMessageArgsBuilder.() -> Unit) {
        val toBeMapped = ServiceBusQueueMessageArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.serviceBusQueueMessage = mapped
    }

    /**
     * @param value Gets or sets the service bus topic message.
     */
    @JvmName("yafngeqrexmqrkps")
    public suspend fun serviceBusTopicMessage(`value`: ServiceBusTopicMessageArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceBusTopicMessage = mapped
    }

    /**
     * @param argument Gets or sets the service bus topic message.
     */
    @JvmName("qckcgdebaolopshj")
    public suspend
    fun serviceBusTopicMessage(argument: suspend ServiceBusTopicMessageArgsBuilder.() -> Unit) {
        val toBeMapped = ServiceBusTopicMessageArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.serviceBusTopicMessage = mapped
    }

    /**
     * @param value Gets or sets the job error action type.
     */
    @JvmName("ngvqbhtxikduckcd")
    public suspend fun type(`value`: JobActionType?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): JobErrorActionArgs = JobErrorActionArgs(
        queueMessage = queueMessage,
        request = request,
        retryPolicy = retryPolicy,
        serviceBusQueueMessage = serviceBusQueueMessage,
        serviceBusTopicMessage = serviceBusTopicMessage,
        type = type,
    )
}
